@@ -43,6 +43,14 @@ BT_OSISHTML::BT_OSISHTML() : sword::OSISHTMLHREF() {
 
 	addTokenSubstitute("seg type=\"morph\"", "<span class=\"morphSegmentation\">");
 	addTokenSubstitute("/seg", "</span>");
+
+	// OSIS tables: <table> and </table> are the same in HTML
+	addTokenSubstitute("row", "<tr>");
+	addTokenSubstitute("/row", "</tr>");
+
+	addTokenSubstitute("cell", "td");
+	addTokenSubstitute("/cell", "/td");
+
 }
 
 bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::BasicFilterUserData *userData) {
@@ -190,10 +198,10 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 					/*     //get the refList value of the right entry attribute
 					     AttributeList notes = myModule->getEntryAttributes()["Footnote"];
 					     bool foundNote = false;
-					     
+
 					     SWBuf id( tag.getAttribute("osisID") );
 					     SWBuf refList;
-					     
+
 					     for (AttributeList::iterator list_it = notes.begin(); (list_it != notes.end()) && !foundNote; ++list_it ) {
 					      for (AttributeValue::iterator val_it = list_it->second.begin(); (val_it != list_it->second.end()) && !foundNote; ++val_it ) {
 					       if ((val_it->first == "osisID") && (val_it->second == id)) {
@@ -202,12 +210,12 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 					       }
 					      }
 					     }
-					 
+
 					     if (refList.length()) {
 					      buf.append(" <span class=\"crossreference\" crossrefs=\"");
 					      buf.append(refList.c_str());
 					      buf.append("\"> ");
-					       
+
 					           myUserData->noteType = BT_UserData::CrossReference;
 					     }
 					     else {
@@ -222,7 +230,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 				     */
 				else if (type == "strongsMarkup") {
 					/**
-					* leave strong's markup notes out, in the future we'll probably have 
+					* leave strong's markup notes out, in the future we'll probably have
 					* different option filters to turn different note types on or off
 					*/
 
@@ -283,15 +291,13 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 					//find out the mod, using the current module makes sense if it's a bible or commentary because the refs link into a bible by default.
 					//If the osisRef is something like "ModuleID:key comes here" then the
 					// modulename is given, so we'll use that one
+
 					CSwordModuleInfo* mod = CPointers::backend()->findSwordModuleByPointer(myModule);
+					Q_ASSERT(mod);
+					if (!mod || (mod->type() != CSwordModuleInfo::Bible
+							&& mod->type() != CSwordModuleInfo::Commentary)) {
 
-					if (mod->type() != CSwordModuleInfo::Bible
-							&& mod->type() != CSwordModuleInfo::Commentary) {
-
-						mod = CBTConfig::get
-								  ( CBTConfig::standardBible );
-
-						//       qWarning("setting standard bible module");
+						mod = CBTConfig::get( CBTConfig::standardBible );
 					}
 
 					Q_ASSERT(mod);
@@ -303,24 +309,27 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 						QString newModuleName = ref.left(pos);
 						hrefRef = ref.mid(pos+1);
 
-						/*      qWarning("found mod-key with mod=%s and key=%s",
-						       newModuleName.latin1(), ref.latin1()
-						      );
-						*/
-
 						if (CPointers::backend()->findModuleByName(newModuleName)) {
 							mod = CPointers::backend()->findModuleByName(newModuleName);
 						}
 					}
 
+					CReferenceManager::ParseOptions options;
+					options.refBase = QString::fromUtf8(myUserData->key->getText());
+					options.refDestinationModule = QString(mod->name());
+					options.sourceLanguage = QString(myModule->Lang());
+					options.destinationLanguage = QString("en");
+
 					buf.append("<a href=\"");
 					buf.append( //create the hyperlink with key and mod
 						CReferenceManager::encodeHyperlink(
-							mod->name(), hrefRef, CReferenceManager::typeFromModule(mod->type())
+							mod->name(),
+							CReferenceManager::parseVerseReference(hrefRef, options),
+							CReferenceManager::typeFromModule(mod->type())
 						).utf8()
 					);
 					buf.append("\" crossrefs=\"");
-					buf.append((const char*)ref.utf8()); //ref must contains the osisRef module marker if there was any
+					buf.append((const char*)CReferenceManager::parseVerseReference(ref, options).utf8()); //ref must contain the osisRef module marker if there was any
 					buf.append("\">");
 				}
 			}
@@ -333,7 +342,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 
 			/*   if (!myUserData->inCrossrefNote && !tag.isEndTag() && !tag.isEmpty() && tag.getAttribute("osisRef")) {
 			        const char* ref = tag.getAttribute("osisRef");
-			    
+
 			    buf.append("<span class=\"crossreference\" crossrefs=\"");
 			    buf.append(ref);
 			    buf.append("\">");
