@@ -52,6 +52,7 @@
 #include <ktoolbar.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
+#include <kdeversion.h>
 
 //Sword includes
 #include <swlog.h>
@@ -72,8 +73,6 @@ void BibleTime::initView() {
 	bookshelfLabel->setMargin(5);
 
 	m_mainIndex = new CMainIndex(vBox);
-	m_mainIndex->initTree();
-	m_mainIndex->setFocusPolicy(WheelFocus);
 
 	m_infoDisplay = new CInfoDisplay(m_leftPaneSplitter);
 	CPointers::setInfoDisplay(m_infoDisplay);
