@@ -16,8 +16,13 @@
 #include <qmap.h>
 
 //KDE includes
+#include <kdeversion.h>
 #include <kapplication.h>
+#if KDE_VERSION >= 0x030200
 #include <kactioncollection.h>
+#else
+#include <kaction.h>
+#endif
 #include <kconfig.h>
 #include <kcharsets.h>
 #include <kglobal.h>
@@ -42,6 +47,8 @@ const QString CBTConfig::getKey( const CBTConfig::strings ID) {
 		return "language";
 		case displayStyle:
 		return "displayStyle";
+		case bookshelfCurrentItem:
+		return "bookshelfCurrentItem";
 	}
 	return QString::null;
 }
@@ -54,6 +61,8 @@ const QString CBTConfig::getDefault( const CBTConfig::strings ID) {
 		return (KGlobal::locale()->language()).local8Bit();
 		case displayStyle:
 		return CDisplayTemplateMgr::defaultTemplate();
+		case bookshelfCurrentItem:
+		return QString();
 	}
 	return QString::null;
 }
@@ -164,11 +173,14 @@ const QString CBTConfig::getKey( const CBTConfig::ints ID) {
 		return "greekAccents";
 		case textualVariants:
 		return "textualVariants";
-		//     case transliteration:     return "transliteration";
 		case scriptureReferences:
 		return "scriptureReferences";
 		case morphSegmentation:
 		return "morphSegmentation";
+		case bookshelfContentsX:
+		return "bookshelfContentsX";
+		case bookshelfContentsY:
+		return "bookshelfContentsY";
 	}
 	return QString::null;
 }
@@ -214,28 +226,31 @@ const bool CBTConfig::getDefault( const CBTConfig::bools ID) {
 const int CBTConfig::getDefault( const CBTConfig::ints ID) {
 	switch ( ID ) {
 		case footnotes:
-		return true;
+		return int(true);
 		case strongNumbers:
-		return true;
+		return int(true);
 		case headings:
-		return true;
+		return int(true);
 		case morphTags:
-		return true;
+		return int(true);
 		case lemmas:
-		return true;
+		return int(true);
 		case hebrewPoints:
-		return true;
+		return int(true);
 		case hebrewCantillation:
-		return true;
+		return int(true);
 		case greekAccents:
-		return true;
+		return int(true);
 		case textualVariants:
-		return false;
-		//     case transliteration:     return 0;
+		return int(false);
 		case scriptureReferences:
-		return true;
+		return int(true);
 		case morphSegmentation:
-		return true;
+		return int(true);
+		case bookshelfContentsX:
+		return 0;
+		case bookshelfContentsY:
+		return 0;
 	}
 	return 0;
 }
@@ -268,6 +283,8 @@ const QString CBTConfig::getKey( const CBTConfig::stringLists ID) {
 		return QString("searchCompletionTexts");
 		case searchTexts:
 		return QString("searchTexts");
+		case bookshelfOpenGroups:
+		return QString("bookshelfOpenGroups");
 	}
 	return QString::null;
 }
@@ -281,6 +298,8 @@ const QStringList CBTConfig::getDefault( const CBTConfig::stringLists ID) {
 		}
 		case searchCompletionTexts:
 		return QStringList();
+		case bookshelfOpenGroups:
+		return QStringList();
 	}
 	return QStringList();
 }
@@ -302,14 +321,14 @@ const CBTConfig::StringMap CBTConfig::getDefault( const CBTConfig::stringMaps ID
 			map.insert(i18n("History"),               QString("Jos - Est"));
 			map.insert(i18n("Prophets"),              QString("Isa - Mal"));
 			map.insert(i18n("New testament"),         QString("Mat - Rev"));
-			map.insert(i18n("Gospels"),             QString("Mat - Joh"));
+			map.insert(i18n("Gospels"),               QString("Mat - Joh"));
 			map.insert(i18n("Letters/Epistles"),      QString("Rom - Jude"));
-			map.insert(i18n("Paul's Epistles"),      QString("Rom - Phile"));
+			map.insert(i18n("Paul's Epistles"),       QString("Rom - Phile"));
 
 			//make the list to the current bookname language!
 			CBTConfig::StringMap::Iterator it;
 			sword::VerseKey vk;
-			vk.setLocale("en");
+			vk.setLocale("en_US");
 
 			for (it = map.begin(); it != map.end(); ++it) {
 				sword::ListKey list = vk.ParseVerseList(it.data().local8Bit(), "Genesis 1:1", true);
