@@ -185,17 +185,16 @@ void COptionsDialog::initDisplay() {
 	);
 	layout->addWidget(m_settings.displayStyle.stylePreview->view());
 
-	CDisplayTemplateMgr* tMgr = CPointers::displayTemplateManager();
-	m_settings.displayStyle.styleChooser->insertStringList( tMgr->availableTemplates() );
+	m_settings.displayStyle.styleChooser->insertStringList(
+		CPointers::displayTemplateManager()->availableTemplates()
+	);
 
-	int i = m_settings.displayStyle.styleChooser->listBox()->index(
-				m_settings.displayStyle.styleChooser->listBox()->findItem(
-					CBTConfig::get
-						(CBTConfig::displayStyle),
-						Qt::CaseSensitive
-					)
-				);
-	m_settings.displayStyle.styleChooser->setCurrentItem( i );
+	for (int i = 0; i < m_settings.displayStyle.styleChooser->count(); ++i) {
+		if ( m_settings.displayStyle.styleChooser->text(i) == CBTConfig::get(CBTConfig::displayStyle) ) {
+			m_settings.displayStyle.styleChooser->setCurrentItem( i );
+			break;
+		}
+	}
 
 	updateStylePreview(); //render it
 }
@@ -770,12 +769,10 @@ void COptionsDialog::saveLanguages() {
 		const CLanguageMgr::Language* const lang = languageMgr()->languageForTranslatedName(it.key());
 		if (!lang->isValid()) { //we probably use a language, for which we have only the abbrev
 			CLanguageMgr::Language l(it.key(), it.key(), it.key()); //create a temp language
-			CBTConfig::set
-				(&l, it.data());
+			CBTConfig::set(&l, it.data());
 		}
 		else {
-			CBTConfig::set
-				(lang, it.data());
+			CBTConfig::set(lang, it.data());
 		}
 	}
 }
@@ -971,11 +968,31 @@ void COptionsDialog::slotKeyChooserTypeChanged(const QString& title) {
 	list.append(m_settings.keys.book.keyChooser);
 
 	//commit all changes in the keychoosers
+#if QT_VERSION >= 0x030200
 	for (KeyChooserList::iterator it(list.begin()); it != list.end(); ++it) {
 		if (*it) { //the list may contain NULL pointers
 			(*it)->commitChanges();
 		}
 	}
+#else
+	//Normally we know a QPtrListIterator is done when it.current() == 0
+	//but now a value can actually be zero, which would be
+	//indistinguishable from the end condition.
+	//Therefore, more complex logic is needed.
+	QPtrListIterator<KKeyChooser> it(list);
+	if (!it.isEmpty()){
+		while (!it.atLast()){
+			if (it.current()){
+				it.current()->commitChanges();
+			}
+			++it;
+		}
+		//We still have the last item to process.
+		if (it.current()){
+			it.current()->commitChanges();
+		}
+	}
+#endif
 	/* Delete all the keychoosers in the list,
 	* the keychoosers are set to NULL, because they are QGuardedPtr
 	*/
