@@ -15,6 +15,9 @@
 #include "util/cpointers.h"
 #include "util/scoped_resource.h"
 
+//We will need to reference this in the Qt includes
+#include <kdeversion.h>
+
 //Qt includes
 #include <qcursor.h>
 #include <qscrollview.h>
@@ -23,6 +26,10 @@
 #include <qpopupmenu.h>
 #include <qlayout.h>
 #include <qtimer.h>
+#if KDE_VERSION < 0x030300
+//We will need to show the error message.
+#include <qmessagebox.h>
+#endif
 
 //KDE includes
 #include <kapplication.h>
@@ -63,9 +70,6 @@ const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDi
 		}
 
 		case SelectedText: {
-			if (!hasSelection())
-				return QString::null;
-
 			if (!hasSelection()) {
 				return QString::null;
 			}
@@ -351,12 +355,12 @@ void CHTMLReadDisplay::khtmlMouseMoveEvent( khtml::MouseMoveEvent* e ) {
 
 			//Code part to show a translation of the hovered word, only works with KDE 3.3
 			/*   if (!infoList.count()) { //translate the text under the mouse, find the lowest node containing the mouse
-			   
+
 			    DOM::Node node = nonSharedNodeUnderMouse();
-			 
+
 			    if (!node.isNull() && node.nodeName().string() == "#text") {
 			      infoList.append( qMakePair(
-			       CInfoDisplay::WordTranslation, 
+			       CInfoDisplay::WordTranslation,
 			       node.nodeValue().string()
 			      )
 			     );
@@ -448,3 +452,16 @@ void CHTMLReadDisplay::zoomOut() {
 	//  qWarning("zooming out");
 	setZoomFactor( (int)((float)zoomFactor()*(1.0/1.1)) );
 }
+
+void CHTMLReadDisplay::openFindTextDialog() {
+#if KDE_VERSION >= 0x030300
+	findText();
+#else
+	QMessageBox::information(0, "Not Supported",
+	"This copy of BibleTime was built against a version of KDE older\n"
+	"than 3.3 (probably due to your distro), so this search feature\n"
+	"does not work.\n\n"
+	"This is a known issue.  If we do not have a fix for the next\n"
+	"version of BibleTime, we will remove the option.");
+#endif
+}
