@@ -33,6 +33,7 @@
 //Qt includes
 
 //KDE includes
+#include <kdeversion.h>
 #include <kaccel.h>
 #include <klocale.h>
 
@@ -65,7 +66,11 @@ CWriteWindow* CDisplayWindow::createWriteInstance(ListCSwordModuleInfo modules,
 }
 
 CDisplayWindow::CDisplayWindow(ListCSwordModuleInfo modules, CMDIArea *parent, const char *name )
+#if KDE_VERSION >= 0x030200
 : KMainWindow(KMainWindow::NoDCOPObject, parent, name, WDestructiveClose),
+#else
+: KMainWindow(parent, name, WDestructiveClose),
+#endif
 m_mdi(parent),
 //    m_modules(modules),
 m_filterOptions(),
@@ -134,8 +139,9 @@ void CDisplayWindow::insertKeyboardActions( KActionCollection* const a ) {
 	KStdAction::zoomIn(0, 0, a, "zoomIn"); //no slot
 	KStdAction::zoomOut(0, 0, a, "zoomOut"); //no slot
 	KStdAction::close(0, 0, a, "closeWindow"); //no slot
-	KStdAction::selectAll(0,0, a, "selectAll");
-	KStdAction::copy(0,0, a, "copySelectedText");
+	KStdAction::selectAll(0, 0, a, "selectAll");
+	KStdAction::copy(0, 0, a, "copySelectedText");
+	KStdAction::find(0, 0, a, "findText");
 
 	new KToolBarPopupAction(
 		i18n("Back in history"),
@@ -183,6 +189,11 @@ void CDisplayWindow::initActions() {
 		actionCollection(), "copySelectedText"
 	);
 
+	KStdAction::find(
+		displayWidget()->connectionsProxy(), SLOT(openFindTextDialog()),
+		actionCollection(), "findText"
+	);
+
 	new KToolBarPopupAction(
 		i18n("Back in history"), CResMgr::displaywindows::general::backInHistory::icon, CResMgr::displaywindows::general::backInHistory::accel,
 		keyChooser(), SLOT( backInHistory() ),
