@@ -1,7 +1,7 @@
 /********* Read the file LICENSE for license details. *********/
 
-/* $Header: /cvsroot/bibletime/bibletime/bibletime/main.cpp,v 1.128 2005/09/02 22:15:30 joachim Exp $ */
-/* $Revision: 1.128 $ */
+/* $Header: /cvsroot/bibletime/bibletime/bibletime/main.cpp,v 1.129 2005/11/06 19:13:09 joachim Exp $ */
+/* $Revision: 1.129 $ */
 
 //standard includes
 #include <stdlib.h>
@@ -143,7 +143,7 @@ int main(int argc, char* argv[]) {
 	*    Active developers (sorted by last name)   *
 	************************************************/
 	// Project coordination
-	aboutData.addAuthor("Joachim Ansorg", I18N_NOOP("Project coordinator"), "junkmail@joachim.ansorgs.de", "http://joachim.ansorgs.de");
+	aboutData.addAuthor("Joachim Ansorg", I18N_NOOP("Project coordinator"), "nospam@joachim-ansorg.de", "http://www.joachim-ansorg.de/");
 	// Second main developer
 	aboutData.addAuthor("Martin Gruner", I18N_NOOP("Frontend, backend"), "mg.pub@gmx.net", "");
 	// artwork
